@@ -216,7 +216,7 @@ fetch_uri_job (GIOSchedulerJob *sched_job,
   MbReleaseFilter filter;
   MbRelease release;
   MbResultList results;
-  gint results_len, idx;
+  gint results_len = 0, idx;
   gchar *retval = NULL;
 
   query = mb_query_new (NULL, NULL);
@@ -226,7 +226,11 @@ fetch_uri_job (GIOSchedulerJob *sched_job,
   filter = mb_release_filter_artist_name (filter, job->artist);
 
   results = mb_query_get_releases (query, filter);
-  results_len = mb_result_list_get_size (results);
+  mb_query_free (query);
+  mb_release_filter_free (filter);
+
+  if (results)
+    results_len = mb_result_list_get_size (results);
 
   for (idx = 0; idx < results_len; idx++) {
     gchar asin[255];
@@ -234,6 +238,8 @@ fetch_uri_job (GIOSchedulerJob *sched_job,
     release = mb_result_list_get_release (results, idx);
     mb_release_get_asin (release, asin, 255);
 
+    mb_release_free (release);
+
     if (asin != NULL &&
         asin[0] != '\0') {
       retval = g_strdup (asin);
@@ -241,6 +247,9 @@ fetch_uri_job (GIOSchedulerJob *sched_job,
     }
   }
 
+  if (results)
+    mb_result_list_free (results);
+
   if (retval == NULL) {
     /* FIXME: do we need a better error? */
     g_simple_async_result_set_error (job->result,
